@@ -9,13 +9,12 @@
  * Functions for reading from the syslog file
  *--------------------------------------------------------------------*/
 
-#ifndef _FIRESTARTER_MAIN
-#define _FIRESTARTER_MAIN
+#ifndef _FIRESTARTER_LOGREAD
+#define _FIRESTARTER_LOGREAD
 
 #include <config.h>
 #include <gnome.h>
 
-int open_logfile (char *logpath);
-
+void open_logfile (char *logpath);
 
 #endif
