@@ -16,12 +16,13 @@
 #include <gnome.h>
 
 GtkWidget *appbar;
-GtkWidget *hitpopup;
-GtkWidget *dynlistpopup;
+
 
 void install_menus_and_toolbar (GtkWidget *app);
-void popup_menu (GtkWidget *clist, GdkEventButton* bevent, GtkWidget *popup);
+void hitview_popup_menu (GdkEventButton *bevent);
 void install_clist_popup (GtkWidget *clist);
 void install_docklet_menu (GtkWidget *eventbox);
 
+void ruleview_popup_menu (GdkEventButton *bevent);
+
 #endif
