@@ -14,14 +14,16 @@
 
 #include <config.h>
 #include <gnome.h>
+#include "firestarter.h"
 
-gint parse_hit_log (char *);
-gchar *get_text_between (gchar *string, gchar *marker1, gchar *marker2);
+Hit *parse_log_line (gchar *line);
 
-void parse_allow_and_deny_all (void);
-void parse_allow_service_machine (void);
-void parse_allow_service_all (void);
-
-void parse_do_not_log_ports (GtkWidget *clist);
+void parse_all_rules (void);
+void parse_trusted_hosts (void);
+void parse_blocked_hosts (void);
+void parse_open_ports (void);
+void parse_stealthed_ports (void);
+void parse_blocked_ports (void);
+void parse_forward (void);
 
 #endif
