@@ -15,6 +15,7 @@
 #include <config.h>
 #include <gnome.h>
 
-gchar* service (gint port, gint proto);
+gchar *get_service_name (gint port, gchar *proto);
+gchar *get_service_name_any_protocol (gint port);
 
 #endif
